@@ -13,7 +13,7 @@ use warnings;
 
 package Games::Risk::GUI::MoveArmies;
 BEGIN {
-  $Games::Risk::GUI::MoveArmies::VERSION = '3.103040';
+  $Games::Risk::GUI::MoveArmies::VERSION = '3.112010';
 }
 # ABSTRACT: window to move armies
 
@@ -23,7 +23,7 @@ use Tk;
 use Tk::Font;
 use Tk::Sugar;
 
-use Games::Risk::I18N qw{ T };
+use Games::Risk::I18n qw{ T };
 
 use constant K => $poe_kernel;
 
@@ -250,7 +250,7 @@ Games::Risk::GUI::MoveArmies - window to move armies
 
 =head1 VERSION
 
-version 3.103040
+version 3.112010
 
 =head1 DESCRIPTION
 
@@ -300,7 +300,7 @@ L<Games::Risk>.
 
 =head1 AUTHOR
 
-  Jerome Quelin
+Jerome Quelin
 
 =head1 COPYRIGHT AND LICENSE
 
